@@ -48,8 +48,8 @@ task_sound(char *action)
 	else if ((action[0] == 'r') || !strcmp(action, "restore"))
 	{
 		sound_init();
-		sound_load_settings();
-		if (get_mute_status)
+		
+		if (get_mute_status())
 			set_mute_status(TRUE);
 	}
 	else
